render_svg_from_input

Function render_svg_from_input 

pub fn render_svg_from_input(
    text: &str,
    from_script: bool,
    style: &StyleSpec,
    layout: &LayoutSpec,
    cursor: &CursorSpec,
    control: &ControlSpec,
) -> String
Render a full SVG output based on raw text input and display mode.

If from_script is true, the text is interpreted as a shell session (e.g. including prompt, commands, output) and rendered in REPL style. Otherwise, it is rendered as a continuous typing animation.

Returns the full SVG string.